@@ -3,7 +3,24 @@
 Define a board of nonogram game
 """
 
-from __future__ import unicode_literals, print_function, division
+from __future__ import division, print_function, unicode_literals
+
+from collections import defaultdict, namedtuple
+from copy import copy
+
+from memoized import memoized
+from six.moves import map, range, zip
+
+from ..utils.cache import init_once
+from ..utils.iter import avg
+from ..utils.other import (from_two_powers, get_named_logger, ignored,
+                           two_powers)
+
+from .color import ColorBlock, normalize_description_colored
+from .common import (BOX, SPACE, SPACE_COLORED, UNKNOWN, BlottedBlock,
+                     NonogramError, invert, is_color_cell,
+                     normalize_description, partial_sums, slack_space)
+from .renderer import Renderer
 
 try:
     from abc import ABC
@@ -13,14 +30,7 @@ except ImportError:
     # https://stackoverflow.com/a/38668373
     ABC = ABCMeta(str('ABC'), (object,), {'__slots__': ()})
 
-from collections import (
-    defaultdict,
-    namedtuple,
-)
-from copy import copy
 
-from memoized import memoized
-from six.moves import zip, range, map
 
 try:
     # noinspection PyPackageRequirements
@@ -28,28 +38,9 @@ try:
 except ImportError:
     np = None
 
-from pynogram.core.common import (
-    UNKNOWN, BOX, SPACE, SPACE_COLORED,
-    invert,
-    normalize_description,
-    is_color_cell,
-    NonogramError,
-    BlottedBlock,
-    partial_sums,
-    slack_space,
-)
-from pynogram.core.color import (
-    normalize_description_colored,
-    ColorBlock,
-)
-from pynogram.core.renderer import Renderer
-from pynogram.utils.cache import init_once
-from pynogram.utils.iter import avg
-from pynogram.utils.other import (
-    two_powers, from_two_powers,
-    get_named_logger,
-    ignored,
-)
+
+
+
 
 LOG = get_named_logger(__name__, __file__)
 
