@@ -3,9 +3,19 @@
 Defines various renderers for the game of nonogram
 """
 
-from __future__ import unicode_literals, print_function, division
+from __future__ import division, print_function, unicode_literals
 
+import codecs
+import logging
 from itertools import combinations
+from sys import stdout
+
+from six import PY2, integer_types, iteritems, itervalues, text_type
+
+from ..utils.iter import max_safe, pad, split_seq
+from ..utils.other import from_two_powers, two_powers
+from .common import (BOX, SPACE, SPACE_COLORED, UNKNOWN, BlottedBlock, Color,
+                     is_color_cell, is_list_like)
 
 try:
     from abc import ABC
@@ -15,35 +25,13 @@ except ImportError:
     # https://stackoverflow.com/a/38668373
     ABC = ABCMeta(str('ABC'), (object,), {'__slots__': ()})
 
-import codecs
-import logging
-from sys import stdout
 
-from six import (
-    integer_types, text_type,
-    iteritems, itervalues,
-    PY2,
-)
 
-from pynogram.core.common import (
-    UNKNOWN, BOX, SPACE, SPACE_COLORED,
-    is_list_like,
-    Color,
-    is_color_cell,
-    BlottedBlock,
-)
-from pynogram.utils.iter import (
-    pad,
-    split_seq,
-    max_safe,
-)
-from pynogram.utils.other import (
-    two_powers, from_two_powers,
-)
 
 _LOG_NAME = __name__
 LOG = logging.getLogger(_LOG_NAME)
 
+
 # prevent "UnicodeEncodeError: 'ascii' codec can't encode character ..."
 # when redirecting output
 if PY2:
